@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
+/*
+    GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: statan.cpp,v 1.2 2007/06/26 15:04:09 cepek Exp $
- */
-
 #include <gnu_gama/statan.h>
 #include <gnu_gama/radian.h>
 
@@ -245,7 +241,7 @@ float KSprob(float lambda)
 
 float Chi_square(float p, int n)
 {
-   if (n < 2)            
+   if (n < 2)
    {
       float a = Normal(0.5*p);
       return a*a;
@@ -277,6 +273,6 @@ float Chi_square(float p, int n)
    return f*z*z*z;
 }
 
-}   // namespace GaMaLib
+}   // namespace GNU_gama::local
 
 //---------------------------------------------------------------------------
