@@ -1,9 +1,9 @@
-/*  
+/*
     C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
-    Copyright (C) 1999, 2007  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 1999, 2007, 2011  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,15 +19,11 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: inderr.h,v 1.5 2008/10/28 12:39:18 cepek Exp $
- *  http://www.gnu.org/software/gama/
- */
-
 #ifndef GNU_gama_gMatVec__IndexErr__h_
 #define GNU_gama_gMatVec__IndexErr__h_
 
 #include <cstddef>
+#include <exception>
 
 namespace GNU_gama {
 
@@ -39,23 +35,23 @@ namespace GNU_gama {
   namespace Exception {
 
     enum
-      { 
-        BadRank,  
-        BadIndex, 
+      {
+        BadRank,
+        BadIndex,
         Singular,
         BadRegularization,
-        NoConvergence,  
-        ZeroDivision,  
+        NoConvergence,
+        ZeroDivision,
         NonPositiveDefinite,
         NotImplemented,
-        StreamError 
+        StreamError
       };
-    
-    class base {
+
+    class base : public std::exception
+    {
     public:
-      virtual ~base() 
-      {
-      }
+      virtual base* clone() const = 0;
+      virtual void  raise() const = 0;
     };
 
     class matvec : public base
@@ -63,9 +59,15 @@ namespace GNU_gama {
     public:
       const int    error;
       const char*  description;
-      
-      matvec(int e, const char* t) : error(e), description(t) 
+
+      matvec(int e, const char* t) : error(e), description(t) {}
+
+      matvec* clone() const { return new matvec(*this); }
+      void    raise() const { throw *this; }
+
+      const char* what() const throw()
       {
+	return description;
       }
     };
   }
