@@ -1,28 +1,23 @@
-/*  
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
-    Copyright (C) 1999, 2001, 2005, 2007  Ales Cepek <cepek@gnu.org>
-
-    This file is part of the GNU Gama C++ Matrix/Vector template library.
-    
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-*/
-
 /*
- *  $Id: svd.h,v 1.5 2008/10/28 12:39:19 cepek Exp $
- *  http://www.gnu.org/software/gama/
- */
+  C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
+  Copyright (C) 1999, 2001, 2005, 2007  Ales Cepek <cepek@gnu.org>
+
+  This file is part of the GNU Gama C++ Matrix/Vector template library.
+
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this library; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
 
 #ifndef GNU_gama_gMatVec_MatSVD__h_
 #define GNU_gama_gMatVec_MatSVD__h_
@@ -35,7 +30,7 @@ namespace GNU_gama {
 
   /** \brief Singular Value Decomposition  */
 
-  /*  Singular Value Decomposition          A = U*W*trans(V) 
+  /*  Singular Value Decomposition          A = U*W*trans(V)
       ############################
 
      SVD is based on the fortran SVD source from package CMLIB
@@ -58,7 +53,9 @@ namespace GNU_gama {
      C     A=USV  of a REAL M by N rectangular matrix.  Householder
      C     bidiagonalization and a variant of the QR algorithm are used.
 
-     ------------------------------------------------------------------------- 
+     -------------------------------------------------------------------------
+
+.....2011-04-17  (AC) suppressed g++ optimization (volatile variables)
 
      2001-02-30  (AC) Occasional problems with SVD convergence:
 
@@ -74,18 +71,18 @@ namespace GNU_gama {
      use a temporary variable s2:
 
         <    if ((s1 + ABS(rv1[L])) == s1) goto test_for_convergence;
-        ---  
-        >    s2 = s1 + ABS(rv1[L]); 
+        ---
+        >    s2 = s1 + ABS(rv1[L]);
         >    if (s1 == s2) goto test_for_convergence;
-             
+
         <    if (s1 + (ABS(W[L1])) == s1) break;
-        ---  
-        >    s2 = s1 + ABS(W[L1]); 
+        ---
+        >    s2 = s1 + ABS(W[L1]);
         >    if (s1 == s2) break;
-             
+
         <    if (s1 + (ABS(f)) == s1) goto test_for_convergence;
-        ---  
-        >    s2 = s1 + ABS(f); 
+        ---
+        >    s2 = s1 + ABS(f);
         >    if (s1 == s2) goto test_for_convergence;
 
      ----------------------------------------------------------------------- */
@@ -143,7 +140,7 @@ namespace GNU_gama {
       Index decomposed;
       void svd();
 
-      Float W_tol;
+      volatile Float W_tol;
       Vec<Float, Exc> inv_W_;
       void set_inv_W();
 
@@ -163,7 +160,7 @@ namespace GNU_gama {
     };      /* class SVD */
 
 
-  // --------- Exception::Singular Value Decompiosition member functions -------------
+  // ------ Exception::Singular Value Decompiosition member functions --------
 
 
   template <typename T> inline const T ABS(const T& x)
@@ -176,7 +173,7 @@ namespace GNU_gama {
     {
       if (W_tol == 0)
         {             // if not defined set W_tol to 1000*comp_epsilon
-          Float  eps, eps_1, eps_min, eps_max, sum;
+          volatile Float  eps, eps_1, eps_min, eps_max, sum;
           const Float one = 1;
 
           eps_min = Float();
@@ -194,7 +191,7 @@ namespace GNU_gama {
           W_tol = 1000*eps;
         }
 
-      Float vmax = Float();
+      volatile Float vmax = Float();
       for (Index k = 1; k <= W_.dim(); k++) if (W[k] > vmax) vmax = W[k];
       const Float vmin = W_tol * vmax;
       defect = 0;
@@ -212,7 +209,7 @@ namespace GNU_gama {
 
   template <typename Float> inline Float PYTHAG( Float a, Float b )
     {
-      Float at, bt, ct;
+      volatile Float at, bt, ct;
 
       return
         (( at = ABS(a) )  > ( bt = ABS(b) ) )     ?
@@ -232,9 +229,9 @@ namespace GNU_gama {
       const Float TWO  = 2;
 
       Index  i, i1, its, j, k, k1, L, L1;
-      Float  c, f, h, s, x, y, z ;
-      Float  s1=ZERO, g=ZERO, scale=ZERO, r, s2;
-      Float  tmp1;
+      volatile Float  c, f, h, s, x, y, z ;
+      volatile Float  s1=ZERO, g=ZERO, scale=ZERO, r, s2;
+      volatile Float  tmp1;
       Index  mn;
 
       reset_UWV();
@@ -326,7 +323,7 @@ namespace GNU_gama {
           {
             for (j=L; j<=n; j++) U[i][j]=ZERO;
           }
-        if (g) 
+        if (g)
           {
             if (i != mn)
               {
@@ -349,55 +346,55 @@ namespace GNU_gama {
       /* Diagonalization of the bidiagonal form */
 
       /* test for splitting */
-      for (k=n; k>=1; k--) 
+      for (k=n; k>=1; k--)
         {
           k1  = k - 1;
           its = 0;
 
           /* test for splitting */
-          for (;;)     // label 520 in fortran source 
+          for (;;)     // label 520 in fortran source
             {
-              for (L=k; L>=1; L--) 
-                {     
-                  s2 = s1 + ABS(rv1[L]); 
+              for (L=k; L>=1; L--)
+                {
+                  s2 = s1 + ABS(rv1[L]);
                   if (s1 == s2) goto test_for_convergence;
-                  
-                  /* rv[1] is always zero, so there is no exit 
+
+                  /* rv[1] is always zero, so there is no exit
                    * through the bottom of the loop */
                   L1 = L - 1;
-                  s2 = s1 + ABS(W[L1]); 
+                  s2 = s1 + ABS(W[L1]);
                   if (s1 == s2) break;
                 }
-              
+
               /* cancellation of rv1[L], if L greater then 1 */
-              c = ZERO;           
+              c = ZERO;
               s = ONE;
-              for (i=L; i<=k; i++) 
+              for (i=L; i<=k; i++)
                 {
                   f = s * rv1[i];
                   rv1[i] = c * rv1[i];
-                  s2 = s1 + ABS(f); 
+                  s2 = s1 + ABS(f);
                   if (s1 == s2) goto test_for_convergence;
                   g = W[i];
                   h = PYTHAG(f,g);
                   W[i] = h;
                   c =  g / h;
                   s = -f / h;
-                  for (j=1; j<=m; j++) 
+                  for (j=1; j<=m; j++)
                     {
                       y = U[j][L1];
                       z = U[j][i];
                       U[j][L1] =  y*c + z*s;
                       U[j][i]  = -y*s + z*c;
-                    }                  
+                    }
                 }
-              
+
             test_for_convergence:
-              
+
               z = W[k];
-              if (L == k) {             
+              if (L == k) {
                 /* W[k] is made nonnegative */
-                if (z < ZERO) 
+                if (z < ZERO)
                   {
                     W[k] = -z;
                     for (j=1; j<=n; j++) V[j][k] = -V[j][k];
@@ -414,7 +411,7 @@ namespace GNU_gama {
               y = W[k1];
               g = rv1[k1];
               h = rv1[k];
-              // f = (Float)0.5*( ((g + z)/h)*((g - z)/y) + y/h -h/y); 
+              // f = (Float)0.5*( ((g + z)/h)*((g - z)/y) + y/h -h/y);
               f = ((y-z)*(y+z)+(g-h)*(g+h))/(TWO*h*y);              // #_LH_#
               g = PYTHAG(f,ONE);
               s = (f >= ZERO) ? g : - g;         // SIGN(g,f)
@@ -422,7 +419,7 @@ namespace GNU_gama {
               f = ((x-z)*(x+z) + h*(y/(f+s) - h))/x;                // #_LH_#
 
               /* next QR transformation */
-              c = s = ONE;        
+              c = s = ONE;
               for (i1=L; i1<=k1; i1++) {
                 i = i1 + 1;
                 g = rv1[i];
@@ -466,15 +463,15 @@ namespace GNU_gama {
             }   // for (;;)
 
         }   // for k
-   
+
       decomposed = 1;
       set_inv_W();
-      if (defect > 0) 
+      if (defect > 0)
         {
           minV = V_;
           if (minx == subset) min_subset_x();
         }
-   
+
     }      /* void SVD<Float, Exc>::svd() */
 
 
@@ -504,7 +501,7 @@ namespace GNU_gama {
                            const Vec<Float, Exc>& w)
     {
       reset(A);
-      Float wi;
+      volatile Float wi;
       for (Index i = 1; i <= A.rows(); i++)
         {
           wi = w(i);
@@ -565,7 +562,7 @@ namespace GNU_gama {
       // A = U*W*trans(V)
       // Covariance = V * inv_W * trans(inv_W) * trans(V);
       if (!decomposed) svd();
-      Float c = Float();
+      volatile Float c = Float();
       for (Index k = 1; k <= n; k++)
         c += V[i][k] * inv_W[k] * inv_W[k] * V[j][k];
       return c;
@@ -580,7 +577,7 @@ namespace GNU_gama {
       // A = U*W*trans(V)
       // Covariance = U * trans(U);
       if (!decomposed) svd();
-      Float c = Float();
+      volatile Float c = Float();
       for (Index k = 1; k <= n; k++)
         if (inv_W[k] != 0)
           c += U[i][k] * U[j][k];
@@ -596,7 +593,7 @@ namespace GNU_gama {
       // A = U*W*trans(V)
       // Covariance = U * trans(V);
       if (!decomposed) svd();
-      Float c = Float();
+      volatile Float c = Float();
       for (Index k = 1; k <= n; k++)
         c += U[i][k] * inv_W[k] * V[j][k];
       return c;
@@ -647,15 +644,15 @@ namespace GNU_gama {
       using namespace std;
 
       if (defect == 0) return;
-      if (defect > n_min) 
+      if (defect > n_min)
         throw Exc(Exception::BadRegularization, "void SVD::min_subset_x()");
 
       Index im;
-      Float s;
+      volatile Float s;
       for (Index k = 1; k <= n; k++)
         if (inv_W[k] == 0)
           {
-            Float Vimk;
+            volatile Float Vimk;
             s = Float();
             for (Index i = 0; i < n_min; i++) {
               im = list_min[i];
@@ -663,8 +660,9 @@ namespace GNU_gama {
               s += Vimk*Vimk;
             }
             s = std::sqrt(s);
-            if (s == 0) 
-              throw Exc(Exception::BadRegularization, "void SVD::min_subset_x()");
+            if (s == 0)
+              throw Exc(Exception::BadRegularization,
+                        "void SVD::min_subset_x()");
             { for (Index i = 1; i <= n; i++) V[i][k] /= s; }   // for ...
 
             for (Index j = 1; j <= n; j++)
@@ -691,7 +689,7 @@ namespace GNU_gama {
       Vec<Float, Exc> t_(n);
       typename Vec<Float, Exc>::const_iterator b = rhs.begin();
       typename Vec<Float, Exc>::iterator t = t_.begin();
-      Float s;
+      volatile Float s;
 
       // t = trans(U)*b*inv(W);
       {   // for ...
@@ -717,6 +715,6 @@ namespace GNU_gama {
 
 
 
-}   // namespace GNU_gama 
+}   // namespace GNU_gama
 
 #endif
