@@ -1,7 +1,7 @@
 /* Slovnikar (lexicographer) is a simple program to compile `dictionaries'
- * used in the GNU GaMa project.
+ * used in the GNU Gama project.
  * ==========================================================================
- * 
+ *
  * Program reads series of file names from standard input. Input files
  * contain translations of texts in the following format:
  *
@@ -11,27 +11,33 @@
  *                        cz="Toto je muj text"  />
  *   <e id="your_text_id" en="This is your text"
  *                        cz="Toto je tvuj text" />
- *       <!-- ...... -->      
- *   </entries>   
+ *       <!-- ...... -->
+ *   </entries>
  *
  * Program compiles dictionarise and write files language.h and language.cpp
  *
  * To ease creation of language files, special attribute EN is
  * available.  Attribute EN is ignored on input and serves as a kind
  * of comment.
- * 
- * $Id: slovnikar.cpp,v 1.14 2006/08/26 13:23:30 cepek Exp $
  *
  * ------------------------------------------------------------------------ */
 
-         const char* language[] = { "en", "ca", "cz", "du", "fi", "fr", 
-                                    "hu", "ru", "ua" };
-  
+         const char* language[] = { "en", "ca", "cz", "du", "es",
+                                    "fi", "fr", "hu", "ru", "ua" };
+
          const int N = sizeof(language)/sizeof(const char*);
 
-         const char* version = "1.09";
+         const char* version = "1.11";
 
 /* ---------------------------------------------------------------------------
+ *
+ * 1.11  2011-04-12
+ *
+ *       - added Spanish (switch "es")
+ *
+ * 1.10  2010-08-14
+ *
+ *       - namespace GNU_gama::local
  *
  * 1.09  2006-08-26
  *
@@ -44,7 +50,7 @@
  * 1.07  2005-08-31
  *
  *       - added French (switch "fr")
- * 
+ *
  * 1.06  2005-08-21
  *
  *       - added Russin (switch "ru")
@@ -63,7 +69,7 @@
  *
  * 1.02  2003-03-16
  *
- *       - processing moved from build-dictionaries to Makefile-slovnikar 
+ *       - processing moved from build-dictionaries to Makefile-slovnikar
  *
  * 1.01  2002-11-22
  *
@@ -81,39 +87,39 @@
  * 0.04  2001-11-28
  *
  *       - all undefined texts set to
- *         "internal error : program must call function set_gama_language()" 
+ *         "internal error : program must call function set_gama_language()"
  *
  * 0.03  2001.05.07
  *
  *       - added function set_gama_language() for dynamic language setting
  *
- * 0.02  2000.08.07 
+ * 0.02  2000.08.07
  *
  *       - language.html review table was added
  *       - language "EN" is ignored (changing "en" to "EN" is used for
  *         commenting out the English texts)
- *         
- * 0.01  2000.08.04  
- *       
+ *
+ * 0.01  2000.08.04
+ *
  *       - first draft
  *
  * ---------------------------------------------------------------------------
- *   
- *   Geodesy and Mapping C++ Library (GaMaLib)
+ *
+ *   Geodesy and Mapping C++ Library (GNU_gama::local)
  *   Copyright (C) 2000, 2006  Ales Cepek <cepek@fsv.cvut.cz>
  *
- *   This file is part of the GaMaLib C++ Library.
- *   
+ *   This file is part of the GNU_gama::local C++ Library.
+ *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Library General Public
  *   License as published by the Free Software Foundation; either
  *   version 2 of the License, or (at your option) any later version.
- *   
+ *
  *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of      
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *   Library General Public License for more details.
- *         
+ *
  *   You should have received a copy of the GNU Library General Public
  *   License along with this library (see COPYING.LIB); if not, write to the
  *   Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -172,14 +178,14 @@ void startElement(void *userData, const char *cname, const char **atts)
   Parser* parser = static_cast<Parser*>(userData);
   const string name(cname);
 
-  if (parser->state == START && name == "entries") 
+  if (parser->state == START && name == "entries")
     {
       parser->state = ENTRIES;
     }
-  else if (parser->state == ENTRIES && name == "e") 
+  else if (parser->state == ENTRIES && name == "e")
     {
       parser->state = ENTRY;
-      
+
       string id;
       Entry  entry, dict_entry;
       while (*atts)
@@ -208,7 +214,7 @@ void startElement(void *userData, const char *cname, const char **atts)
               }
           if (lang == N) parser->error("unknown language");
         }
-      
+
       if (id == "")
         parser->error("id not defined");
       else
@@ -217,10 +223,10 @@ void startElement(void *userData, const char *cname, const char **atts)
             {
               if (entry.lang[l] == "") continue;
 
-              if (dict_entry.lang[l] != ""  && 
+              if (dict_entry.lang[l] != ""  &&
                   dict_entry.lang[l] != entry.lang[l])
                 {
-                  string txt = id + " / " 
+                  string txt = id + " / "
                     + string(language[l]) + " = "
                     + entry.lang[l] + " redefined";
                   parser->error(txt.c_str());
@@ -263,16 +269,16 @@ void characterDataHandler(void *userData, const char* s, int len)
 
 Parser::Parser(string fn)
 {
-  expat_parser = XML_ParserCreate(0); 
-  
+  expat_parser = XML_ParserCreate(0);
+
   XML_SetUserData(expat_parser, this);
   XML_SetElementHandler(expat_parser, startElement, endElement);
   XML_SetCharacterDataHandler(expat_parser, characterDataHandler);
   XML_SetUnknownEncodingHandler(expat_parser, UnknownEncodingHandler, 0);
-  
+
   filename = fn;
   state = START;
-  
+
   ifstream inp(filename.c_str());
   if (!inp) cerr << "cannot open file " << filename << endl;
   while (getline(inp, text))
@@ -284,7 +290,7 @@ Parser::Parser(string fn)
           errString = string(XML_ErrorString(XML_GetErrorCode(expat_parser)));
           errCode   = XML_GetErrorCode(expat_parser);
           errLine   = XML_GetCurrentLineNumber(expat_parser);
-          
+
           cerr << filename << ":" << errLine << ": "
                << errString << " : " << text << endl;
           return;
@@ -295,21 +301,21 @@ Parser::Parser(string fn)
 
 Parser::~Parser()
 {
-  XML_ParserFree(expat_parser); 
+  XML_ParserFree(expat_parser);
 }
 
 void Parser::error(const char* message)
 {
   int erl = XML_GetCurrentLineNumber(expat_parser);
-  cerr << filename << ":" << erl << ": " << message << ": " << text << endl; 
+  cerr << filename << ":" << erl << ": " << message << ": " << text << endl;
   result = 1;
 }
 
 int main()
 {
-  /* reading all input files*/ 
+  /* reading all input files*/
   {
-    string f;  
+    string f;
     while (cin >> f) { Parser p(f); };
   }
 
@@ -317,10 +323,10 @@ int main()
   {
     ofstream out("language.h");
 
-    out << "#ifndef GaMaLib___language__header_file_h\n";
-    out << "#define GaMaLib___language__header_file_h\n\n";
+    out << "#ifndef GNU_gama_local___language__header_file_h\n";
+    out << "#define GNU_gama_local___language__header_file_h\n\n";
 
-    out << "namespace GaMaLib {      /* slovnikar " << version << " */\n\n";
+    out << "namespace GNU_gama { namespace local {      /* slovnikar " << version << " */\n\n";
 
     out << "enum gama_language {";
     for (int N=sizeof(language)/sizeof(const char*)-1, i=0; i<=N; i++)
@@ -336,7 +342,7 @@ int main()
         out << "extern const char* " << (*i).first << ";\n";
       }
 
-    out << "\n}\n\n";
+    out << "\n}}\n\n";
     out << "#endif\n";
   }
 
@@ -351,21 +357,21 @@ int main()
       "<html xmlns=\"http://www.w3.org/1999/xhtml\""
       " xml:lang=\"en\" lang=\"en\">\n"
       "  <head>\n"
-      "    <title>GaMa lang</title>\n"
+      "    <title>GNU Gama lang</title>\n"
       "  </head>\n"
       "<body>\n\n"
-      "<h1>GaMa lang</h1>\n\n"
+      "<h1>GNU Gama lang</h1>\n\n"
       "<table border=\"1\">\n\n";
 
       for (Dictionary::const_iterator i=dict.begin(); i!=dict.end(); ++i)
         {
-          out << "<tr><td colspan=\"2\"><tt style=\"color : navy\">" 
+          out << "<tr><td colspan=\"2\"><tt style=\"color : navy\">"
               << (*i).first << "</tt></td></tr>\n";
           for (int l=0; l<N; l++)
             {
               out << "<tr>"
                   << "<td>" << language[l] << "</td>"
-                  << "<td>"; 
+                  << "<td>";
 
               string s = (*i).second.lang[l];
               for (string::const_iterator c=s.begin(); c!=s.end(); ++c)
@@ -379,7 +385,7 @@ int main()
                   out << *c;
 
               out << "</td>"
-                  << "</tr>\n";  
+                  << "</tr>\n";
             }
         }
 
@@ -390,8 +396,8 @@ int main()
   {
     ofstream out("language.cpp");
     out << "/* slovnikar " << version << " */\n\n"
-        << "#include <gamalib/language.h>\n\n"
-        << "namespace GaMaLib {\n\n"
+        << "#include <gnu_gama/local/language.h>\n\n"
+        << "namespace GNU_gama { namespace local {\n\n"
         << "const char* T_language_cpp_internal_error = "
         << "\" internal error : "
         << "program must call function set_gama_language() \";\n\n";
@@ -399,8 +405,8 @@ int main()
     Dictionary::const_iterator i;
     for (i=dict.begin(); i!=dict.end(); ++i)
       {
-        out << "const char* " 
-            << (*i).first 
+        out << "const char* "
+            << (*i).first
             << " = T_language_cpp_internal_error;\n";
       }
     out << endl;
@@ -417,25 +423,16 @@ int main()
       for (i=dict.begin(); i!=dict.end(); ++i)
         {
           string text = (*i).second.lang[l];
-          if (text == "") 
+          if (text == "")
             text = (*i).second.lang[0];   // English is used implicitly
-          
+
           out << "\t" << (*i).first << "=\"" << text << "\";\n";
         }
         out << "\treturn;\n\n";
-      
+
       }
-    out << "   }\n\n}\n\n}   // namespace GaMaLib\n\n";
+    out << "   }\n\n}\n\n}}   // namespace GNU_gama::local\n";
   }
-  
+
   return result;
 }
-
-
-
-
-
-
-
-
-
